netapp_ontap.models.version API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.version`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VersionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Version object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `full GET`

    The full cluster version string.

    Example: NetApp Release 9.4.0: Sun Nov 05 18:20:57 UTC 2017

  `generation GET`

    The generation portion of the version.

    Example: 9

  `major GET`

    The major portion of the version.

    Example: 4

  `minor GET`

    The minor portion of the version.

    Example: 0